
.. include:: notebooks/readme.rst

Navigation
----------

.. toctree::
   :maxdepth: 2
   :name: mastertoc

   notebooks/00-installation
   notebooks/01-configuration
   notebooks/02-interface
   notebooks/70-data_analysis
   notebooks/75-data_visualizations
   notebooks/76-default_visualizations
   notebooks/80-stimuli_delivery
   notebooks/81-default_stimuli_delivery_paradigms
   notebooks/90-event_marker_synchronization
   notebooks/91-eeg_records_exploring
   notebooks/99-ilustrative_example

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

    